@@ -1,66 +1,64 @@
 
 from collections import OrderedDict
 from collections import namedtuple
+from ..util.iter import map_numeric_indices
 
 
+# noinspection DuplicatedCode
 class flux_row_cls:
 
     class_names = {'_headers',
-                   'values',
+                   '_view_as_array',
                    'names',
+                   'values',
+                   'is_header_row',
                    'dict',
-                   'namedtuples'}
+                   'namedtuple'}
 
     def __init__(self, headers, values):
         """
         :param headers: OrderedDict of {'header': index}
-
-            * headers is a single dictionary passed byref from the
-              flux_cls to many flux_row_cls instances
-            * this eliminates need for all flux_row_cls objects
-              to maintain a seprate copy of these mappings and
-              allows for centralized and instantaneous updatdes
-
+            headers is a single dictionary passed byref from the flux_cls to many flux_row_cls instances
+            this eliminates need for all flux_row_cls objects to maintain a seprate copy of these mappings and
+            allows for centralized and instantaneous updatdes
         :param values: list of underlying data
 
-        self.__dict__ is used to set attributes in __init__ so as to avoid
-        premature __setattr__ lookups
+        (properties must be set on self.__dict__ instead of directly on self to prevent
+         premature __setattr__ lookups)
         """
         self.__dict__['_headers'] = headers
         self.__dict__['values']   = values
 
     @property
-    def names(self):
-        return list(self._headers.keys())
-
-    @property
-    def view_as_array(self):
-        """ for development purposes; used purely to trigger a debugging feature in PyCharm
+    def _view_as_array(self):
+        """ to help with debugging; meant to trigger a debugging feature in PyCharm
 
         PyCharm will recognize returned the (name, value) pairs as an ndarray
         and enable the "...view as array" option in the debugger which displays
-        values in a special window
+        values in a special window as a table
         """
         import numpy
         return numpy.transpose([self.names, self.values])
 
+    @property
+    def names(self):
+        return list(self._headers.keys())
+
+    def is_header_row(self):
+        """ determine if underlying values match self._headers.keys
+
+        self.names == self.values will not always work, since map_numeric_indices()
+        was used to modify self._headers values into more suitable dictionary keys,
+        like modifying duplicate values to ensure they are unique, etc
+        """
+        header_names = list(map_numeric_indices(self.values).keys())
+        return self.names == header_names
+
     def dict(self):
         return OrderedDict(zip(self.names, self.values))
 
-    def namedtuples(self, nt_cls=None):
-        try:
-            if nt_cls is None:
-                nt_cls = namedtuple('flux_row_nt', self.names)
-
-            return nt_cls(*self.values)
-        except ValueError as e:
-            import re
-
-            names = [n for n in self.names if re.search('^[^a-z]|[ ]', str(n), re.I)]
-            if names:
-                raise ValueError('invalid field(s) for namedtuple constructor: {}'.format(names)) from e
-            else:
-                raise e
+    def namedtuple(self):
+        return namedtuple('flux_row_ntc', self.names)(*self.values)
 
     def __getattr__(self, name):
         """  eg:
@@ -90,7 +88,10 @@ class flux_row_cls:
             i = self._headers.get(name, name)
             self.values[i] = value
         except (TypeError, IndexError) as e:
-            raise AttributeError(self.__attr_err_msg(name)) from e
+            if name in self.__dict__:
+                self.__dict__[name] = value
+            else:
+                raise AttributeError(self.__attr_err_msg(name)) from e
 
     def __setitem__(self, name, value):
         """ eg:
@@ -100,13 +101,16 @@ class flux_row_cls:
             i = self._headers.get(name, name)
             self.values[i] = value
         except (TypeError, IndexError) as e:
-            raise AttributeError(self.__attr_err_msg(name)) from e
+            if name in self.__dict__:
+                self.__dict__[name] = value
+            else:
+                raise AttributeError(self.__attr_err_msg(name)) from e
 
     def __attr_err_msg(self, name):
         if isinstance(name, slice):
-            return 'slice should be used on row.values\n(eg, row.values[2:5], not row[2:5])'
+            return 'slice should be used directly on row.values\n(eg, row.values[2:5], not row[2:5])'
 
-        names = '\n\t'.join(self.names)
+        names = '\n\t'.join(str(n) for n in self.names)
         return "No flux_row_cls column named '{}'\navailable columns:\n\t{}".format(name, names)
 
     def __getstate__(self):
@@ -144,14 +148,17 @@ class flux_row_cls:
 class lev_row_cls(flux_row_cls):
 
     class_names = {'_headers',
-                   'values',
+                   '_view_as_array',
                    'names',
+                   'values',
+                   'address',
+                   'is_header_row',
                    'dict',
-                   'namedtuples',
-                   'address'}
+                   'namedtuples'}
 
-    def __init__(self, headers, values, address):
+    def __init__(self, headers, values, address=''):
         super().__init__(headers, values)
+
         self.__dict__['address'] = address
 
     def __repr__(self):
