@@ -1,5 +1,5 @@
 
-# Excel's integer codes for cell errors
+# Excel's integer values for cell errors
 excel_errors = {-2146826281: 'error div0',
                 -2146826246: 'error na',
                 -2146826259: 'error name',
@@ -9,10 +9,7 @@ excel_errors = {-2146826281: 'error div0',
                 -2146826273: 'error value',
                 -2146826281: 'error div0'}
 
-# colors
-xlClear = -4142
-
-# find parameters
+# range.find parameters
 xlCellTypeFormulas = -4123
 xlValues           = -4163
 xlErrors           = 16
@@ -25,6 +22,10 @@ xlByColumns        = 2
 xlUp               = -4162
 xlToRight          = -4161
 
+# colors
+xlClear = -4142
+xlNone  = -4142
+
 # other enums
 xlPasteColumnWidths    = 8
 xlMaximized            = -4137
@@ -33,3 +34,5 @@ xlCalculationAutomatic = -4105
 
 
 
+
+
